These JSON files define the serialization schema of several components of the system. 

The serialization can be re-generated using the following command:

```bash
python3 scripts/generate_serialization.py
```